<?php
require_once ("Mysession.php");

class Mysession_db extends Mysession {

	protected function db_controller ($parms) {


		try {
			$dbh = new PDO($parms['DNS'], $parms['user'],$parms['password']);

			$sql = 'SELECT * FROM '.$parms['table'].' WHERE userid LIKE :USERNAME AND userpass LIKE :PASS';
			

			$sth = $dbh->prepare( $sql);

			
			$sth ->bindValue(':USERNAME',$parms['userid']);
			$sth ->bindValue(':PASS',$parms['userpass']);

			
			$sth->execute();
			$result = $sth->fetchAll();
			$colcount = count($result);		
		}

		catch (PDOException $e)  {
			echo $e->getMessage();

		}



		$dbh = null;

		if($colcount === 1) {
			$this->errmsg = (boolean)true;	
			
			$this->setsession($result[0]['userid'],$result[0]['username']);
		}
		
		elseif($result != true ) {
			$this->errmsg = Mysession::ERROR_MISS;
			
		}
	}
	
}
